@@ -25,10 +25,12 @@ pub use crate::cell_renderer_pixbuf::CellRendererPixbufExtManual;
 pub use crate::color_button::ColorButtonExtManual;
 pub use crate::color_chooser::ColorChooserExtManual;
 pub use crate::combo_box::ComboBoxExtManual;
+pub use crate::container::ContainerExtManual;
 pub use crate::dialog::DialogExtManual;
 pub use crate::drag_context::DragContextExtManual;
 pub use crate::entry::EntryExtManual;
 pub use crate::entry_completion::EntryCompletionExtManual;
+pub use crate::file_chooser::FileChooserExtManual;
 pub use crate::fixed::FixedExtManual;
 pub use crate::flow_box::FlowBoxExtManual;
 #[cfg(any(feature = "v3_24", feature = "dox"))]
@@ -39,10 +41,8 @@ pub use crate::invisible::InvisibleExtManual;
 pub use crate::list_box::ListBoxExtManual;
 pub use crate::list_store::GtkListStoreExtManual;
 pub use crate::menu::GtkMenuExtManual;
-#[cfg(any(feature = "v3_20", feature = "dox"))]
 pub use crate::native_dialog::NativeDialogExtManual;
 pub use crate::notebook::NotebookExtManual;
-#[cfg(any(feature = "v3_20", feature = "dox"))]
 pub use crate::stack_switcher::StackSwitcherExtManual;
 pub use crate::style_context::StyleContextExtManual;
 pub use crate::switch::SwitchExtManual;
