@@ -8,7 +8,6 @@ use glib::subclass::prelude::*;
 use glib::translate::*;
 use glib::Cast;
 use glib::GString;
-use glib::Object;
 
 use crate::CellEditable;
 use crate::CellRenderer;
@@ -17,65 +16,52 @@ use crate::SizeRequestMode;
 use crate::Widget;
 
 pub trait CellRendererImpl: CellRendererImplExt + ObjectImpl {
-    fn request_mode(&self, renderer: &Self::Type) -> SizeRequestMode {
-        self.parent_request_mode(renderer)
+    fn request_mode(&self) -> SizeRequestMode {
+        self.parent_request_mode()
     }
 
-    fn preferred_width<P: IsA<Widget>>(&self, renderer: &Self::Type, widget: &P) -> (i32, i32) {
-        self.parent_preferred_width(renderer, widget)
+    fn preferred_width<P: IsA<Widget>>(&self, widget: &P) -> (i32, i32) {
+        self.parent_preferred_width(widget)
     }
 
     #[doc(alias = "get_preferred_width_for_height")]
-    fn preferred_width_for_height<P: IsA<Widget>>(
-        &self,
-        renderer: &Self::Type,
-        widget: &P,
-        height: i32,
-    ) -> (i32, i32) {
-        self.parent_preferred_width_for_height(renderer, widget, height)
+    fn preferred_width_for_height<P: IsA<Widget>>(&self, widget: &P, height: i32) -> (i32, i32) {
+        self.parent_preferred_width_for_height(widget, height)
     }
 
     #[doc(alias = "get_preferred_height")]
-    fn preferred_height<P: IsA<Widget>>(&self, renderer: &Self::Type, widget: &P) -> (i32, i32) {
-        self.parent_preferred_height(renderer, widget)
+    fn preferred_height<P: IsA<Widget>>(&self, widget: &P) -> (i32, i32) {
+        self.parent_preferred_height(widget)
     }
 
     #[doc(alias = "get_preferred_height_for_width")]
-    fn preferred_height_for_width<P: IsA<Widget>>(
-        &self,
-        renderer: &Self::Type,
-        widget: &P,
-        width: i32,
-    ) -> (i32, i32) {
-        self.parent_preferred_height_for_width(renderer, widget, width)
+    fn preferred_height_for_width<P: IsA<Widget>>(&self, widget: &P, width: i32) -> (i32, i32) {
+        self.parent_preferred_height_for_width(widget, width)
     }
 
     #[doc(alias = "get_aligned_area")]
     fn aligned_area<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         widget: &P,
         flags: CellRendererState,
         cell_area: &gdk::Rectangle,
     ) -> gdk::Rectangle {
-        self.parent_aligned_area(renderer, widget, flags, cell_area)
+        self.parent_aligned_area(widget, flags, cell_area)
     }
 
     fn render<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         cr: &cairo::Context,
         widget: &P,
         background_area: &gdk::Rectangle,
         cell_area: &gdk::Rectangle,
         flags: CellRendererState,
     ) {
-        self.parent_render(renderer, cr, widget, background_area, cell_area, flags);
+        self.parent_render(cr, widget, background_area, cell_area, flags);
     }
 
     fn activate<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         event: Option<&gdk::Event>,
         widget: &P,
         path: &str,
@@ -83,20 +69,11 @@ pub trait CellRendererImpl: CellRendererImplExt + ObjectImpl {
         cell_area: &gdk::Rectangle,
         flags: CellRendererState,
     ) -> bool {
-        self.parent_activate(
-            renderer,
-            event,
-            widget,
-            path,
-            background_area,
-            cell_area,
-            flags,
-        )
+        self.parent_activate(event, widget, path, background_area, cell_area, flags)
     }
 
     fn start_editing<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         event: Option<&gdk::Event>,
         widget: &P,
         path: &str,
@@ -104,60 +81,40 @@ pub trait CellRendererImpl: CellRendererImplExt + ObjectImpl {
         cell_area: &gdk::Rectangle,
         flags: CellRendererState,
     ) -> Option<CellEditable> {
-        self.parent_start_editing(
-            renderer,
-            event,
-            widget,
-            path,
-            background_area,
-            cell_area,
-            flags,
-        )
+        self.parent_start_editing(event, widget, path, background_area, cell_area, flags)
     }
 
-    fn editing_canceled(&self, renderer: &Self::Type) {
-        self.parent_editing_canceled(renderer)
+    fn editing_canceled(&self) {
+        self.parent_editing_canceled()
     }
 
-    fn editing_started(&self, renderer: &Self::Type, editable: &CellEditable, path: &str) {
-        self.parent_editing_started(renderer, editable, path)
+    fn editing_started(&self, editable: &CellEditable, path: &str) {
+        self.parent_editing_started(editable, path)
     }
 }
 
 pub trait CellRendererImplExt: ObjectSubclass {
-    fn parent_request_mode(&self, renderer: &Self::Type) -> SizeRequestMode;
-    fn parent_preferred_width<P: IsA<Widget>>(
-        &self,
-        renderer: &Self::Type,
-        widget: &P,
-    ) -> (i32, i32);
+    fn parent_request_mode(&self) -> SizeRequestMode;
+    fn parent_preferred_width<P: IsA<Widget>>(&self, widget: &P) -> (i32, i32);
     fn parent_preferred_width_for_height<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         widget: &P,
         height: i32,
     ) -> (i32, i32);
-    fn parent_preferred_height<P: IsA<Widget>>(
-        &self,
-        renderer: &Self::Type,
-        widget: &P,
-    ) -> (i32, i32);
+    fn parent_preferred_height<P: IsA<Widget>>(&self, widget: &P) -> (i32, i32);
     fn parent_preferred_height_for_width<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         widget: &P,
         width: i32,
     ) -> (i32, i32);
     fn parent_aligned_area<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         widget: &P,
         flags: CellRendererState,
         cell_area: &gdk::Rectangle,
     ) -> gdk::Rectangle;
     fn parent_render<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         cr: &cairo::Context,
         widget: &P,
         background_area: &gdk::Rectangle,
@@ -166,7 +123,6 @@ pub trait CellRendererImplExt: ObjectSubclass {
     );
     fn parent_activate<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         event: Option<&gdk::Event>,
         widget: &P,
         path: &str,
@@ -176,7 +132,6 @@ pub trait CellRendererImplExt: ObjectSubclass {
     ) -> bool;
     fn parent_start_editing<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         event: Option<&gdk::Event>,
         widget: &P,
         path: &str,
@@ -184,28 +139,25 @@ pub trait CellRendererImplExt: ObjectSubclass {
         cell_area: &gdk::Rectangle,
         flags: CellRendererState,
     ) -> Option<CellEditable>;
-    fn parent_editing_canceled(&self, renderer: &Self::Type);
-    fn parent_editing_started(&self, renderer: &Self::Type, editable: &CellEditable, path: &str);
+    fn parent_editing_canceled(&self);
+    fn parent_editing_started(&self, editable: &CellEditable, path: &str);
 }
 
 impl<T: CellRendererImpl> CellRendererImplExt for T {
-    fn parent_request_mode(&self, renderer: &Self::Type) -> SizeRequestMode {
+    fn parent_request_mode(&self) -> SizeRequestMode {
         unsafe {
             let data = T::type_data();
             let parent_class = data.as_ref().parent_class() as *mut ffi::GtkCellRendererClass;
             let f = (*parent_class).get_request_mode.unwrap();
-            from_glib(f(renderer
+            from_glib(f(self
+                .obj()
                 .unsafe_cast_ref::<CellRenderer>()
                 .to_glib_none()
                 .0))
         }
     }
 
-    fn parent_preferred_width<P: IsA<Widget>>(
-        &self,
-        renderer: &Self::Type,
-        widget: &P,
-    ) -> (i32, i32) {
+    fn parent_preferred_width<P: IsA<Widget>>(&self, widget: &P) -> (i32, i32) {
         unsafe {
             let data = T::type_data();
             let parent_class = data.as_ref().parent_class() as *mut ffi::GtkCellRendererClass;
@@ -214,7 +166,10 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
             let mut minimum_size = mem::MaybeUninit::uninit();
             let mut natural_size = mem::MaybeUninit::uninit();
             f(
-                renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0,
+                self.obj()
+                    .unsafe_cast_ref::<CellRenderer>()
+                    .to_glib_none()
+                    .0,
                 widget.as_ref().to_glib_none().0,
                 minimum_size.as_mut_ptr(),
                 natural_size.as_mut_ptr(),
@@ -225,7 +180,6 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
 
     fn parent_preferred_width_for_height<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         widget: &P,
         height: i32,
     ) -> (i32, i32) {
@@ -237,7 +191,10 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
             let mut minimum_size = mem::MaybeUninit::uninit();
             let mut natural_size = mem::MaybeUninit::uninit();
             f(
-                renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0,
+                self.obj()
+                    .unsafe_cast_ref::<CellRenderer>()
+                    .to_glib_none()
+                    .0,
                 widget.as_ref().to_glib_none().0,
                 height,
                 minimum_size.as_mut_ptr(),
@@ -246,11 +203,7 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
             (minimum_size.assume_init(), natural_size.assume_init())
         }
     }
-    fn parent_preferred_height<P: IsA<Widget>>(
-        &self,
-        renderer: &Self::Type,
-        widget: &P,
-    ) -> (i32, i32) {
+    fn parent_preferred_height<P: IsA<Widget>>(&self, widget: &P) -> (i32, i32) {
         unsafe {
             let data = T::type_data();
             let parent_class = data.as_ref().parent_class() as *mut ffi::GtkCellRendererClass;
@@ -258,7 +211,10 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
             let mut minimum_size = mem::MaybeUninit::uninit();
             let mut natural_size = mem::MaybeUninit::uninit();
             f(
-                renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0,
+                self.obj()
+                    .unsafe_cast_ref::<CellRenderer>()
+                    .to_glib_none()
+                    .0,
                 widget.as_ref().to_glib_none().0,
                 minimum_size.as_mut_ptr(),
                 natural_size.as_mut_ptr(),
@@ -268,7 +224,6 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
     }
     fn parent_preferred_height_for_width<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         widget: &P,
         width: i32,
     ) -> (i32, i32) {
@@ -279,7 +234,10 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
             let mut minimum_size = mem::MaybeUninit::uninit();
             let mut natural_size = mem::MaybeUninit::uninit();
             f(
-                renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0,
+                self.obj()
+                    .unsafe_cast_ref::<CellRenderer>()
+                    .to_glib_none()
+                    .0,
                 widget.as_ref().to_glib_none().0,
                 width,
                 minimum_size.as_mut_ptr(),
@@ -291,7 +249,6 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
 
     fn parent_aligned_area<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         widget: &P,
         flags: CellRendererState,
         cell_area: &gdk::Rectangle,
@@ -302,7 +259,10 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
             let mut aligned_area = gdk::Rectangle::uninitialized();
             let f = (*parent_class).get_aligned_area.unwrap();
             f(
-                renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0,
+                self.obj()
+                    .unsafe_cast_ref::<CellRenderer>()
+                    .to_glib_none()
+                    .0,
                 widget.as_ref().to_glib_none().0,
                 flags.into_glib(),
                 cell_area.to_glib_none().0,
@@ -314,7 +274,6 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
 
     fn parent_render<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         cr: &cairo::Context,
         widget: &P,
         background_area: &gdk::Rectangle,
@@ -326,7 +285,10 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
             let parent_class = data.as_ref().parent_class() as *mut ffi::GtkCellRendererClass;
             if let Some(f) = (*parent_class).render {
                 f(
-                    renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0,
+                    self.obj()
+                        .unsafe_cast_ref::<CellRenderer>()
+                        .to_glib_none()
+                        .0,
                     cr.to_glib_none().0,
                     widget.as_ref().to_glib_none().0,
                     background_area.to_glib_none().0,
@@ -339,7 +301,6 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
 
     fn parent_activate<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         event: Option<&gdk::Event>,
         widget: &P,
         path: &str,
@@ -352,7 +313,10 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
             let parent_class = data.as_ref().parent_class() as *mut ffi::GtkCellRendererClass;
             if let Some(f) = (*parent_class).activate {
                 from_glib(f(
-                    renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0,
+                    self.obj()
+                        .unsafe_cast_ref::<CellRenderer>()
+                        .to_glib_none()
+                        .0,
                     mut_override(event.to_glib_none().0),
                     widget.as_ref().to_glib_none().0,
                     path.to_glib_none().0,
@@ -368,7 +332,6 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
 
     fn parent_start_editing<P: IsA<Widget>>(
         &self,
-        renderer: &Self::Type,
         event: Option<&gdk::Event>,
         widget: &P,
         path: &str,
@@ -381,7 +344,10 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
             let parent_class = data.as_ref().parent_class() as *mut ffi::GtkCellRendererClass;
             if let Some(f) = (*parent_class).start_editing {
                 from_glib_none(f(
-                    renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0,
+                    self.obj()
+                        .unsafe_cast_ref::<CellRenderer>()
+                        .to_glib_none()
+                        .0,
                     mut_override(event.to_glib_none().0),
                     widget.as_ref().to_glib_none().0,
                     path.to_glib_none().0,
@@ -395,23 +361,30 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
         }
     }
 
-    fn parent_editing_canceled(&self, renderer: &Self::Type) {
+    fn parent_editing_canceled(&self) {
         unsafe {
             let data = T::type_data();
             let parent_class = data.as_ref().parent_class() as *mut ffi::GtkCellRendererClass;
             if let Some(f) = (*parent_class).editing_canceled {
-                f(renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0)
+                f(self
+                    .obj()
+                    .unsafe_cast_ref::<CellRenderer>()
+                    .to_glib_none()
+                    .0)
             }
         }
     }
 
-    fn parent_editing_started(&self, renderer: &Self::Type, editable: &CellEditable, path: &str) {
+    fn parent_editing_started(&self, editable: &CellEditable, path: &str) {
         unsafe {
             let data = T::type_data();
             let parent_class = data.as_ref().parent_class() as *mut ffi::GtkCellRendererClass;
             if let Some(f) = (*parent_class).editing_started {
                 f(
-                    renderer.unsafe_cast_ref::<CellRenderer>().to_glib_none().0,
+                    self.obj()
+                        .unsafe_cast_ref::<CellRenderer>()
+                        .to_glib_none()
+                        .0,
                     editable.to_glib_none().0,
                     path.to_glib_none().0,
                 )
@@ -422,7 +395,11 @@ impl<T: CellRendererImpl> CellRendererImplExt for T {
 
 unsafe impl<T: CellRendererImpl> IsSubclassable<T> for CellRenderer {
     fn class_init(class: &mut ::glib::Class<Self>) {
-        <Object as IsSubclassable<T>>::class_init(class);
+        Self::parent_class_init::<T>(class);
+
+        if !crate::rt::is_initialized() {
+            panic!("GTK has to be initialized first");
+        }
 
         let klass = class.as_mut();
         klass.get_request_mode = Some(cell_renderer_get_request_mode::<T>);
@@ -439,20 +416,15 @@ unsafe impl<T: CellRendererImpl> IsSubclassable<T> for CellRenderer {
         klass.editing_started = Some(cell_renderer_editing_started::<T>);
         klass.editing_canceled = Some(cell_renderer_editing_canceled::<T>);
     }
-
-    fn instance_init(instance: &mut glib::subclass::InitializingObject<T>) {
-        <Object as IsSubclassable<T>>::instance_init(instance);
-    }
 }
 
 unsafe extern "C" fn cell_renderer_get_request_mode<T: CellRendererImpl>(
     ptr: *mut ffi::GtkCellRenderer,
 ) -> ffi::GtkSizeRequestMode {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
 
-    imp.request_mode(wrap.unsafe_cast_ref()).into_glib()
+    imp.request_mode().into_glib()
 }
 
 unsafe extern "C" fn cell_renderer_get_preferred_width<T: CellRendererImpl>(
@@ -462,11 +434,10 @@ unsafe extern "C" fn cell_renderer_get_preferred_width<T: CellRendererImpl>(
     natptr: *mut c_int,
 ) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
     let widget: Borrowed<Widget> = from_glib_borrow(wdgtptr);
 
-    let (min_size, nat_size) = imp.preferred_width(wrap.unsafe_cast_ref(), &*widget);
+    let (min_size, nat_size) = imp.preferred_width(&*widget);
     if !minptr.is_null() {
         *minptr = min_size;
     }
@@ -483,12 +454,10 @@ unsafe extern "C" fn cell_renderer_get_preferred_height_for_width<T: CellRendere
     nat_height_ptr: *mut c_int,
 ) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
     let widget: Borrowed<Widget> = from_glib_borrow(wdgtptr);
 
-    let (min_height, nat_height) =
-        imp.preferred_height_for_width(wrap.unsafe_cast_ref(), &*widget, width);
+    let (min_height, nat_height) = imp.preferred_height_for_width(&*widget, width);
     if !min_height_ptr.is_null() {
         *min_height_ptr = min_height;
     }
@@ -504,11 +473,10 @@ unsafe extern "C" fn cell_renderer_get_preferred_height<T: CellRendererImpl>(
     natptr: *mut c_int,
 ) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
     let widget: Borrowed<Widget> = from_glib_borrow(wdgtptr);
 
-    let (min_size, nat_size) = imp.preferred_height(wrap.unsafe_cast_ref(), &*widget);
+    let (min_size, nat_size) = imp.preferred_height(&*widget);
     if !minptr.is_null() {
         *minptr = min_size;
     }
@@ -525,12 +493,10 @@ unsafe extern "C" fn cell_renderer_get_preferred_width_for_height<T: CellRendere
     nat_width_ptr: *mut c_int,
 ) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
     let widget: Borrowed<Widget> = from_glib_borrow(wdgtptr);
 
-    let (min_width, nat_width) =
-        imp.preferred_width_for_height(wrap.unsafe_cast_ref(), &*widget, height);
+    let (min_width, nat_width) = imp.preferred_width_for_height(&*widget, height);
     if !min_width_ptr.is_null() {
         *min_width_ptr = min_width;
     }
@@ -547,16 +513,10 @@ unsafe extern "C" fn cell_renderer_get_aligned_area<T: CellRendererImpl>(
     alignedptr: *mut gdk::ffi::GdkRectangle,
 ) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
     let widget: Borrowed<Widget> = from_glib_borrow(wdgtptr);
 
-    let rectangle = imp.aligned_area(
-        wrap.unsafe_cast_ref(),
-        &*widget,
-        from_glib(flags),
-        &from_glib_borrow(cellarea),
-    );
+    let rectangle = imp.aligned_area(&*widget, from_glib(flags), &from_glib_borrow(cellarea));
     *alignedptr = *rectangle.to_glib_none().0;
 }
 
@@ -569,13 +529,11 @@ unsafe extern "C" fn cell_renderer_render<T: CellRendererImpl>(
     flags: ffi::GtkCellRendererState,
 ) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
     let widget: Borrowed<Widget> = from_glib_borrow(wdgtptr);
     let cr: Borrowed<cairo::Context> = from_glib_borrow(crptr);
 
     imp.render(
-        wrap.unsafe_cast_ref(),
         &cr,
         &*widget,
         &from_glib_borrow(bgptr),
@@ -594,13 +552,11 @@ unsafe extern "C" fn cell_renderer_activate<T: CellRendererImpl>(
     flags: ffi::GtkCellRendererState,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
     let widget: Borrowed<Widget> = from_glib_borrow(wdgtptr);
     let evt: Borrowed<Option<gdk::Event>> = from_glib_borrow(evtptr);
 
     imp.activate(
-        wrap.unsafe_cast_ref(),
         evt.as_ref().as_ref(),
         &*widget,
         &GString::from_glib_borrow(pathptr),
@@ -621,13 +577,11 @@ unsafe extern "C" fn cell_renderer_start_editing<T: CellRendererImpl>(
     flags: ffi::GtkCellRendererState,
 ) -> *mut ffi::GtkCellEditable {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
     let widget: Borrowed<Widget> = from_glib_borrow(wdgtptr);
     let evt: Borrowed<Option<gdk::Event>> = from_glib_borrow(evtptr);
 
     imp.start_editing(
-        wrap.unsafe_cast_ref(),
         evt.as_ref().as_ref(),
         &*widget,
         &GString::from_glib_borrow(pathptr),
@@ -643,10 +597,9 @@ unsafe extern "C" fn cell_renderer_editing_canceled<T: CellRendererImpl>(
     ptr: *mut ffi::GtkCellRenderer,
 ) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
 
-    imp.editing_canceled(wrap.unsafe_cast_ref());
+    imp.editing_canceled();
 }
 
 unsafe extern "C" fn cell_renderer_editing_started<T: CellRendererImpl>(
@@ -655,13 +608,8 @@ unsafe extern "C" fn cell_renderer_editing_started<T: CellRendererImpl>(
     pathptr: *const c_char,
 ) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<CellRenderer> = from_glib_borrow(ptr);
+    let imp = instance.imp();
     let editable = from_glib_borrow(editableptr);
 
-    imp.editing_started(
-        wrap.unsafe_cast_ref(),
-        &editable,
-        &GString::from_glib_borrow(pathptr),
-    );
+    imp.editing_started(&editable, &GString::from_glib_borrow(pathptr));
 }
