@@ -1,6 +1,5 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use crate::Bin;
 use crate::ListBoxRow;
 
 use glib::subclass::prelude::*;
@@ -10,25 +9,22 @@ use glib::Cast;
 use super::bin::BinImpl;
 
 pub trait ListBoxRowImpl: ListBoxRowImplExt + BinImpl {
-    fn activate(&self, list_box_row: &Self::Type) {
-        self.parent_activate(list_box_row)
+    fn activate(&self) {
+        self.parent_activate()
     }
 }
 
 pub trait ListBoxRowImplExt: ObjectSubclass {
-    fn parent_activate(&self, list_box_row: &Self::Type);
+    fn parent_activate(&self);
 }
 
 impl<T: ListBoxRowImpl> ListBoxRowImplExt for T {
-    fn parent_activate(&self, list_box_row: &Self::Type) {
+    fn parent_activate(&self) {
         unsafe {
             let data = T::type_data();
             let parent_class = data.as_ref().parent_class() as *mut ffi::GtkListBoxRowClass;
             if let Some(f) = (*parent_class).activate {
-                f(list_box_row
-                    .unsafe_cast_ref::<ListBoxRow>()
-                    .to_glib_none()
-                    .0)
+                f(self.obj().unsafe_cast_ref::<ListBoxRow>().to_glib_none().0)
             }
         }
     }
@@ -36,21 +32,20 @@ impl<T: ListBoxRowImpl> ListBoxRowImplExt for T {
 
 unsafe impl<T: ListBoxRowImpl> IsSubclassable<T> for ListBoxRow {
     fn class_init(class: &mut ::glib::Class<Self>) {
-        <Bin as IsSubclassable<T>>::class_init(class);
+        Self::parent_class_init::<T>(class);
+
+        if !crate::rt::is_initialized() {
+            panic!("GTK has to be initialized first");
+        }
 
         let klass = class.as_mut();
         klass.activate = Some(list_box_row_activate::<T>);
     }
-
-    fn instance_init(instance: &mut glib::subclass::InitializingObject<T>) {
-        <Bin as IsSubclassable<T>>::instance_init(instance);
-    }
 }
 
 unsafe extern "C" fn list_box_row_activate<T: ListBoxRowImpl>(ptr: *mut ffi::GtkListBoxRow) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
-    let wrap: Borrowed<ListBoxRow> = from_glib_borrow(ptr);
+    let imp = instance.imp();
 
-    imp.activate(wrap.unsafe_cast_ref())
+    imp.activate()
 }
